/* 
 * File:   Dds.h
 * Author: Anthony (f4goh@orange.fr)
 *
 * Created on 20 juin 2024
 */

#ifndef DDS_H
#define DDS_H
#include <Arduino.h>
#include <math.h>

#define SYNC 4                      //gpio D2 pour led

#define ATTENUATION 2
#define SAMPLING_FREQUENCY 62500.0


class Dds {
public:
  Dds();

  Dds(const Dds& orig);
  virtual ~Dds();

  void begin();

  void setFrequency(float freq1,float freq2);
  void stop();
  void start();
  void off();
  void setPhase(uint16_t ph1,uint16_t ph2);
  void setIQ();
  void delay(int ms);


  static void marshall();

private:

  void interruption();


  static Dds* anchor;
  volatile uint16_t accumulateur1;  // Accumulateur de phase
  volatile uint16_t accumulateur2;  // Accumulateur de phase
  uint8_t sinusTable[256];
 

protected:
  uint16_t computeIncrementPhase(float freq);

  volatile uint16_t incrementPhase1;  // Increment de phase1 courant
  volatile uint16_t incrementPhase2;  // Increment de phase2 courant
  volatile uint16_t dephase1;         // Valeur du déphasage1
  volatile uint16_t dephase2;         // Valeur du déphasage2
  volatile uint16_t compteur;        // Compteur d'échantillons
  volatile bool ddsState;
};

#endif /* DDS_H */
